# -*- encoding: utf-8 -*-

import os
from paste.script import templates


RENOMMAGES = {'gitignore': '.gitignore'}


class DjangoTemplate(templates.Template):
    """
    Modèle de projet Django pour l'AUF reposant sur
    `Buildout <http://www.buildout.org/>`_.

    Il permet de construire un projet avec les briques de base
    importantes pour la maintenance et l'homogénéité entre les applications.

    **Utilisation**::

        paster create -t auf_django


    **Les fichiers squelettes**:

    *buildout.cfg*

    .. literalinclude:: ../auf/skeleton/django/templates/django/\
            buildout.cfg_tmpl

    *devel.cfg*

    .. literalinclude:: ../auf/skeleton/django/templates/django/\
            devel.cfg_tmpl

    *versions.cfg*

    .. literalinclude:: ../auf/skeleton/django/templates/django/\
            versions.cfg_tmpl

    """
    egg_plugins = ['auf.skeleton.django']
    summary = 'Démarrer un nouveau projet Django avec Buildout'
    use_cheetah = True

    vars = [
        templates.var('module_name', u'nom du module projet?',
        default='project'),
        templates.var('django_version', u'Version de Django?',),
    ]

    def post(self, command, output_dir, vars):
        for avant, apres in RENOMMAGES.items():
            avant = os.path.join(output_dir, avant)
            apres = os.path.join(output_dir, apres)
            os.rename(avant, apres)
        print ""
        print "Génération du projet terminée."
        print ""
        print "* Paquets requis"
        print "- python-virtualenv"
        print "- python-mysqldb"
        print "- git-core"
        print ""
        print ""
        print "* : cd %s" % output_dir
        print "* : python bootstrap.py"
        print "* : bin/buildout -c devel.cfg"
        print "* : Configurer conf.py"
        print "* : bin/django syncdb"
        print "* : bin/django migrate"
        print "* : git push origin <depot>"


class Django13Template(DjangoTemplate):
    _template_dir = 'templates/django_1_3'
